#!/bin/sh

usage() {
    echo -e -n "\n"
    echo "Usage: _internalInstallPackage.sh [options...] <package name> [PackageInstalled , InstallationServiceExecuted , GlobalAssetMigrated , InstancedMigrated]"
    echo -e -n "\n" 
    echo "Options:"
    echo "    -?, -help                             print this message"
    echo "    -h <host>, -host <host>               host of the process server where to deploy the package"
    echo "    -t <port>, -port <port>               port of the process server where to deploy the package"
    echo "    -u <username>, -username <username>   user name of the process server administrator"
    echo "    -p <password>, -password <password>   user password (unencrypted)"
    echo "    -profileName <name>                   profile name"
    echo "    -nodeName <name>                      node name in an ND Environment"
    echo "    -serverName <name>                    server name in an ND Environment"
    echo -e -n "\n"
    exit $1
}

ORIG_DIR=`pwd`
BIN_DIR=`dirname ${0}`/../../../../bin
cd $BIN_DIR
. ./setupCmdLine.sh
cd $ORIG_DIR

FILE=
HOST=
PORT=
USERNAME=
PASSWORD=
NODENAME=
SERVERNAME=

FINISHED='0'
until [ "$#" = "1" -o "$#" = "0" -o $FINISHED = '1' ]
do
    case "$1" in
        '-help'|'-?')
            usage 0
            ;;
        '-host'|'-h')
            HOST="$2"
            shift;shift
            ;;
        '-port'|'-t')
            PORT="$2"
            shift;shift
            ;;
        '-username'|'-u')
            USERNAME="$2"
            shift;shift
            ;;
        '-password'|'-p')
            PASSWORD="$2"
            shift;shift
            ;;
        '-profileName')
            PROFILENAME="$2"
            shift;shift
            ;;
        '-nodeName')
            NODENAME="$2"
            shift;shift
            ;;
        '-serverName')
            SERVERNAME="$2"
            shift;shift
            ;;
        *)
            FINISHED='1'
            ;;
    esac
done

if [ ! "$1" ]
then
    echo -e -n "\n"
    echo "Package name is missing."
    echo -e -n "\n"
    usage 1
fi

if [ ! "$2" ]
then
    echo -e -n "\n"
    echo "Installation state is missing."
    echo -e -n "\n"
    usage 1
fi

PLATFORM=`/bin/uname`

if [ "$PLATFORM" = "AIX" ]; then 
	FILE="$(cd $(dirname $1); pwd)/$(basename $1)"
else
	FILE="$1"
fi


if [ "$NODENAME" ] && [ "$SERVERNAME" ]
    then
    "${WAS_HOME}"/bin/ws_ant.sh \
        -f "${WAS_HOME}"/BPM/base/profile/actions/processAppPackageManager.ant \
        -DWAS_HOME="${WAS_HOME}" \
        -DprofileName=${PROFILENAME} \
        -DnodeName=${NODENAME} \
        -DserverName=${SERVERNAME} \
        -Dhost=${HOST} \
        -Dport=${PORT} \
        -Dusername=${USERNAME} \
        -Dpassword=${PASSWORD} \
        -Dfile="${FILE}" \
        -Dstate=${2} \
        installPackage
elif [ ! "$NODENAME" ] && [ ! "$SERVERNAME" ]
    then
    "${WAS_HOME}"/bin/ws_ant.sh \
        -f "${WAS_HOME}"/BPM/base/profile/actions/processAppPackageManager.ant \
        -DWAS_HOME="${WAS_HOME}" \
        -DprofileName=${PROFILENAME} \
        -Dhost=${HOST} \
        -Dport=${PORT} \
        -Dusername=${USERNAME} \
        -Dpassword=${PASSWORD} \
        -Dfile="${FILE}" \
        -Dstate=${2} \
        installPackage
else
    echo -e -n "\n"
    echo "Incorrect combination of parameters specified."
    echo -e -n "\n"
    usage 1
fi

if [ "$?" -ne "0" ]
then
    exit ${1}
fi
