#!/bin/sh

echo ""
echo "IBM Business Process Manager 8.0 Search Optimization - Schema Generator"
echo ""

usage() {
  echo -e -n "\n"
  echo "Generates schema for pivot tables."
  echo -e -n "\n"
  echo "Usage:"
  echo -e -n "\n"
  echo "   SchemaGenerator.sh [-profileName <name>] options"
  echo -e -n "\n"
  echo "Options:"
  echo "  -execute"
  echo "     The tool should go ahead and create all the schema."
  echo "  -output <FILENAME>"
  echo "     Instead of directly creating the schema, the tool should write all the SQL statements it would normally run to modify"
  echo "     the database, to the file <FILENAME>."
  echo "  -screen"
  echo "     Instead of directly creating the schema, the tool should write all the SQL statements it would normally run to modify"
  echo "     the database, to stdout."
  echo -e -n "\n"
  echo "  -?, -help"
  echo "     This help message"
  echo -e -n "\n"
  exit $1
}

SCRIPT_DIR=`dirname ${0}`
ORIG_DIR=`pwd`
BIN_DIR=$SCRIPT_DIR/../../../../bin
REPLACE_WAS_HOME=$SCRIPT_DIR/../../../../
. $BIN_DIR/setupCmdLine.sh

if [ "${USER_INSTALL_ROOT:=}" = "" ]; then
  echo -e -n "\n"
  echo "Profile does not exist."
  echo -e -n "\n"
  usage 1
fi

if [ -f ${JAVA_HOME}/bin/java ]; then
  JAVA_EXE="${JAVA_HOME}/bin/java"
else
  JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

LOGGING_PROP="-Dcom.lombardisoftware.ant.JULDefaultLogger.level=DEBUG -Djava.util.logging.config.file=$SCRIPT_DIR/loggingCreate.properties -Dtw.log4j.init=false"
LOGGING_PROP="$LOGGING_PROP -Dcom.lombardi.logging.StringFilter.excludes=contains(db.password);equals(WSVR0072W);equals(WSVR0801I);equals(WKSP0500)"

ENABLE_DEBUG=false

if [ $ENABLE_DEBUG = true ]; then
   DEBUG_PROP="-Xdebug -Xrunjdwp:transport=dt_socket,address=1111,server=y,suspend=y"   
else
   DEBUG_PROP= 
fi

FINISHED='0'
until [ $FINISHED = '1' ]
do
  case "$1" in
    '-?'|'-help')
      usage 0
      ;;
    '-profileName')
      shift;shift
      ;;
    '-execute'|'-output'|'-screen')
      FINISHED='1'
      ;;
    *)
      usage 0
      ;;
  esac
done

PLUGINS_DIR=$WAS_HOME/plugins
RUNTIMES_DIR=$WAS_HOME/runtimes
BPM_LIB_DIR=$WAS_HOME/BPM/Lombardi/lib

CLASSPATH=$SCRIPT_DIR
CLASSPATH=$CLASSPATH:lib/search-opt.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.admin.core.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.admin.services.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.admin.system.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.bpm.repository.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.bpm.utils.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.bpm.wccm.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.emf.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.runtime.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.wsspi.extension.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.wsspi.proxy.extension.jar
CLASSPATH=$CLASSPATH:$RUNTIMES_DIR/com.ibm.ws.admin.client_8.0.0.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/langutil.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/log4j.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/psapiclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/psclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/pssearch.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/svrcoreclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/jdom.jar

$JAVA_EXE $DEBUG_PROP $LOGGING_PROP -Dwas.install.root=${WAS_HOME} -Dcom.ibm.ws.management.standalone=true -Dwas.repository.root=$USER_INSTALL_ROOT/config -Duser.install.root=$USER_INSTALL_ROOT -classpath $CLASSPATH com.lombardisoftware.tools.optimization.search.SchemaGenerator $1 $2 $3
